@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2018 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2025 (C) Thomas Liske <thomas@fiasko-nw.net>
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,14 @@ use Locale::TextDomain 'needrestart';
 
 needrestart_ui_register(__PACKAGE__, NEEDRESTART_PRIO_LOW);
 
+# The default is to be interactive
+my $INTERACTIVE = 1;
+
+sub interactive {
+    my $self = shift;
+    $INTERACTIVE = shift;
+}
+
 sub _announce {
     my $self = shift;
     my $message = shift;
@@ -43,7 +51,7 @@ sub _announce {
 					 kversion => $vars{KVERSION},
 					 message => $message,
 		   ));
-    <STDIN> if (-t *STDIN && -t *STDOUT);
+    <STDIN> if (-t *STDIN && -t *STDOUT && $INTERACTIVE);
 }
 
 
@@ -77,7 +85,7 @@ You should consider rebooting!
 
 EHINT
 
-    <STDIN> if (-t *STDIN && -t *STDOUT);
+    <STDIN> if (-t *STDIN && -t *STDOUT && $INTERACTIVE);
 }
 
 
@@ -86,11 +94,11 @@ sub announce_ucode {
     my %vars = @_;
 
     print "\n";
-    $self->wprint(\*STDOUT, '', '', __x("Pending processor microcode upgrade!\n\nDiagnostics:\n  The currently running processor microcode signature is {CURRENT} which is not the expected microcode signature {AVAIL}.\n\nRestarting the system to load the new processor microcode will not be handled automatically, so you should consider rebooting. [Return]\n",
+    $self->wprint(\*STDOUT, '', '', __x("Pending processor microcode upgrade!\n\nDiagnostics:\n  The currently running processor microcode revision is {current} which is not the expected microcode revision {avail}.\n\nRestarting the system to load the new processor microcode will not be handled automatically, so you should consider rebooting. [Return]\n",
 			 current => $vars{CURRENT},
 			 avail => $vars{AVAIL},
 		   ));
-    <STDIN> if (-t *STDIN && -t *STDOUT);
+    <STDIN> if (-t *STDIN && -t *STDOUT && $INTERACTIVE);
 }
 
 
